import { Configuration } from './config';
import { ServiceResponse } from './response';
import { Service } from './service';
/** The production TCPS service url. */
export declare const DefaultTCPSServiceUri = "https://app.connect.trimble.com/tc/api/2.0/";
export interface ConnectObject {
    /** The object origin server. */
    origin: string;
}
export interface Server extends ConnectObject {
    isMaster?: boolean;
    location?: string;
}
export interface FileSystemEntry extends ConnectObject {
    id: string;
    name: string;
    type: 'FILE' | 'FOLDER';
    versionId?: string;
    parentId?: string;
    parentType?: 'FOLDER' | 'TODO';
    createdOn?: string;
    createdBy?: User;
    modifiedOn?: string;
    modifiedBy?: User;
    size?: number;
    projectId?: string;
    path?: Array<{
        id: string;
        name: string;
        versionId?: string;
    }>;
}
export interface FileEntry extends FileSystemEntry {
    hash?: string;
    checkedOutOn?: string;
    checkedOutBy?: User;
    thumbnailUrl?: string[];
    revision?: number;
    status?: 'PENDING' | 'ON HOLD' | 'DONE' | 'CANCELLED' | 'ERROR' | 'PROCESSING';
    runtimeType?: 'POTREE' | 'TRIMBIM' | 'PDF';
    runtimeId?: string;
}
export interface UpdateFileEntryRequest {
    id: string;
    name?: string;
    parentId?: string;
    processingNofitySet?: boolean;
}
export interface Files {
    [modelId: string]: FileEntry;
}
export interface FolderEntry extends FileSystemEntry {
    hasChildren?: boolean;
    permission?: 'READ' | 'FULL_ACCESS';
}
export interface Folders {
    [filelId: string]: FolderEntry;
}
export interface Project extends ConnectObject {
    id: string;
    name: string;
    rootId: string;
    thumbnail?: string;
    location?: string;
    lastVisitedOn?: string;
    modifiedOn?: string;
    createdOn?: string;
    createdBy?: User;
    modifiedBy?: User;
    updatedOn?: string;
    updatedBy?: User;
    size?: number;
    filesCount?: number;
    foldersCount?: number;
    versionsCount?: number;
    usersCount?: number;
    description?: string;
    license?: {
        id?: string;
        usedInvites?: number;
    };
    access?: 'FULL_ACCESS' | 'NO_ACCESS';
}
export interface User {
    id: string;
    firstName: string;
    lastName: string;
    email: string;
    status: 'ACTIVE' | 'PENDING' | 'REMOVED';
}
export interface UserDetails extends User {
    company: {
        id: string;
        name: string;
        website: string;
        image: string;
    };
    companyAdmin: boolean;
    language: string;
    createdOn: string;
    modifiedOn: string;
    podLocation: string;
    thumbnail: string;
    timeZone: string;
    title: string;
    role?: string;
    viewerBackground: {
        r: number;
        g: number;
        b: number;
        a: number;
    };
}
export interface UserGroup {
    id: string;
    name: string;
    projectId: string;
    createdBy: User;
    modifiedBy: User;
    createdOn: string;
    modifiedOn: string;
    usersCount: number;
}
export interface Placement {
    id?: string;
    locationX?: number;
    locationY?: number;
    locationZ?: number;
    axisX?: number;
    axisY?: number;
    axisZ?: number;
    refDirectionX?: number;
    refDirectionY?: number;
    refDirectionZ?: number;
    scale?: number;
    versionId?: string;
    fileId?: string;
    createdOn?: string;
    modifiedOn?: string;
    createdBy?: User;
    modifiedBy?: User;
}
export interface Camera {
    cameraId?: string;
    targetX?: number;
    targetY?: number;
    targetZ?: number;
    upX?: number;
    upY?: number;
    upZ?: number;
    distance?: number;
    pitch?: number;
    yaw?: number;
    projectionType?: 'ortho' | 'perspective';
    viewAngle: number;
    viewScale: number;
    viewId?: string;
}
export interface Element {
    isRecursive?: boolean;
    priority?: number;
    sourceId?: string;
    state?: number;
    versionId?: string;
    color?: Color;
}
export interface ElementType {
    type?: string;
    state?: number;
    priority?: number;
    color?: Color;
}
export interface Presentation {
    ghost?: boolean;
    transparent?: boolean;
    wireframe?: boolean;
    transparencyLevel?: number;
    isNewEnabled?: boolean;
    isPendingEnabled?: boolean;
    isCriticalEnabled?: boolean;
    isResolvedEnabled?: boolean;
    isIgnoredEnabled?: boolean;
    isNotesEnabled?: boolean;
    isDocumentsEnabled?: boolean;
    elementTypes?: ElementType[];
    elements?: Element[];
}
export interface SectionPlane {
    sectionPlaneId?: string;
    directionX?: number;
    directionY?: number;
    directionZ?: number;
    positionX?: number;
    positionY?: number;
    positionZ?: number;
    viewId?: string;
    createdOn?: string;
    modifiedOn?: string;
    createdBy?: User;
    modifiedBy?: User;
}
export interface Color {
    r?: number;
    g?: number;
    b?: number;
    a?: number;
}
export interface Line {
    id?: string;
    positionX?: number;
    positionY?: number;
    positionZ?: number;
    position2X?: number;
    position2Y?: number;
    position2Z?: number;
    deleted?: boolean;
}
export interface MeasurementPick {
    type?: 'point' | 'line' | 'lineSegment' | 'plane';
    positionX?: number;
    positionY?: number;
    positionZ?: number;
    position2X?: number;
    position2Y?: number;
    position2Z?: number;
    directionX?: number;
    directionY?: number;
    directionZ?: number;
    referenceObject?: string;
}
export interface Markup {
    markupId?: string;
    projectId?: string;
    mashupId?: string;
    createdOn?: string;
    modifiedOn?: string;
    createdBy?: User;
    modifiedBy?: User;
    type?: 'measure' | 'measure_with_pick' | 'text' | 'arrow' | 'line' | 'cloud' | 'redlines';
    positionX?: number;
    positionY?: number;
    positionZ?: number;
    color?: Color;
    planeA?: number;
    planeB?: number;
    planeC?: number;
    planeD?: number;
    width?: number;
    height?: number;
    position2X?: number;
    position2Y?: number;
    position2Z?: number;
    screenSpaceDistance?: number;
    text?: string;
    camera?: Camera;
    lines?: Line[];
    unitType?: 'Metric';
    quantityUnit?: 'millimeter';
    quantityUnitFormat?: 'mm';
    start?: MeasurementPick;
    end?: MeasurementPick;
}
export interface ToDo extends ConnectObject {
    id?: string;
    label?: string;
    type?: string;
    title?: string;
    description?: string;
    dueDate?: string;
    percentComplete?: number;
    status?: 'NEW' | 'IN PROGRESS' | 'WAITING' | 'DONE' | 'CLOSED';
    priority?: 'LOW' | 'NORMAL' | 'HIGH' | 'CRITICAL';
    projectId?: string;
    createdOn?: string;
    createdBy?: User;
    modifiedOn?: string;
    modifiedBy?: User;
    assignees?: User[];
}
export declare type CommentObjectType = 'FILE' | 'FOLDER' | 'VIEW' | 'CLASH' | 'RELEASE' | 'TODO';
export interface CreateCommentRequest {
    description: string;
    objectId: string;
    objectType: CommentObjectType;
}
export interface Comment extends ConnectObject {
    id?: string;
    description?: string;
    objectId?: string;
    objectType?: CommentObjectType;
    createdOn?: string;
    createdBy?: User;
}
export declare type AttachmentType = 'VIEW' | 'FILE' | 'CLASHSET' | 'CLASHITEM' | 'VIEW2D' | 'URL';
export interface Attachment extends ConnectObject {
    id?: string;
    name?: string;
    type?: AttachmentType;
    versionId?: string;
    modifiedOn?: string;
    modifiedBy?: User;
    revision?: string;
    url?: string;
    urlName?: string;
    embedded?: boolean;
}
export interface ClashSource {
    sourceId?: string;
    versionId?: string;
}
export interface Clash extends ConnectObject {
    id?: string;
    label?: string;
    distance?: number;
    element1Uuid?: string;
    element2Uuid?: string;
    modifiedBy?: User;
    modifiedOn?: string;
    size?: number;
    sourceId1?: ClashSource;
    sourceId2?: ClashSource;
}
export interface ClashItem extends ConnectObject {
    id?: string;
    label?: string;
    distance?: number;
    sourceId1?: ClashSource;
    sourceId2?: ClashSource;
    clashGeometry?: string;
    element1Uuid?: string;
    element2Uuid?: string;
    elementName1?: string;
    elementName2?: string;
    elementType1?: string;
    elementType2?: string;
}
export interface View extends ConnectObject {
    id?: string;
    name?: string;
    description?: string;
    projectId?: string;
    models?: string[];
    files?: string[];
    imageData?: string;
    thumbnail?: string;
    createdOn?: string;
    modifiedOn?: string;
    modifiedBy?: User;
    createdBy?: User;
    assignees?: User[];
    camera?: Camera;
    sectionPlanes?: SectionPlane[];
    markups?: Markup[];
    presentation?: Presentation;
}
export interface ViewGroup extends ConnectObject {
    id?: string;
    projectId?: string;
    name?: string;
    views?: string[];
    createdOn?: string;
    createdBy?: User;
    modifiedOn?: string;
    modifiedBy?: User;
}
export declare enum ViewEntityStates {
    Selected = 1,
    Hidden = 4,
    SelectedHidden = 5,
    Visible = 6,
    SlectedVisible = 7,
    Highlighted = 8
}
export declare type ShareMode = "PROJECT_USERS" | "REGISTERED_USERS" | "PUBLIC";
export declare type SharePermission = "VIEW" | "DOWNLOAD";
export interface ShareObject {
    id: string;
    type: "FILE";
    url: string;
    useLatestVersion: true;
}
export interface Share extends ConnectObject {
    accessToken?: string;
    createdBy?: User;
    createdOn?: string;
    expiryDate?: string | "never";
    id?: string;
    mode?: ShareMode;
    modifiedBy?: User;
    modifiedOn?: string;
    objects?: ShareObject[];
    permission?: SharePermission;
    projectId?: string;
}
export interface Tag extends ConnectObject {
    id?: string;
    label?: string;
    description?: string;
    projectId?: string;
    createdOn?: string;
    createdBy?: User;
    modifiedOn?: string;
    modifiedBy?: User;
}
export declare type TagObjectType = 'FOLDER' | 'FILE' | 'TODO' | 'VIEW';
export interface ObjectLink {
    fileId: string;
    versionId: string;
    objectId: string;
    targetId: string;
    targetType: string;
}
export interface LinkData {
    type?: string;
    objectId?: string;
    sourceId?: string;
    xrefId?: string;
}
export interface LinkSource {
    id?: string;
    versionId?: string;
    type?: string;
    data?: LinkData[];
}
export interface LinkTarget {
    type?: string;
    name?: string;
    id?: string;
    versionId?: string;
}
export interface Link {
    id?: string;
    name?: string;
    modifiedBy?: User;
    createdBy?: User;
    createdOn?: string;
    modifiedOn?: string;
    source?: LinkSource;
    target?: LinkTarget;
}
export interface UnitSettings {
    unitsystem: string;
    lengthunit: string;
    lengthunitformat: string;
    lengthmeasurementunit: string;
    lengthmeasurementunitformat: string;
    areaunit: string;
    areaunitformat: string;
    volumeunit: string;
    volumeunitformat: string;
    weightunit: string;
    weightunitformat: string;
    angularunit: string;
    angularunitformat: string;
}
export interface ProjectSettings {
    unitSettings?: UnitSettings;
    isTodosRestricted?: boolean;
    isProjectInviteRestricted?: boolean;
}
export declare type FileParentType = 'FOLDER' | 'TODO' | 'COMMENT' | 'OBJECTLINK';
export declare type LinkTargetType = 'FILE' | 'TODO' | 'VIEW' | 'CLASH' | 'URL';
export interface UrlResponse {
    url: string;
}
export interface StatusResponse {
    status: number;
}
/**
 * The service client that represents connection to the TCPS (Trimble Connect Platform Services).
 * Each API operation is exposed as a function on service.
 */
export declare class TCPS extends Service {
    /**
     * Determines whether the item is a file.
     * @param item The folder item.
     */
    static isFile(item: FileEntry | FolderEntry): item is FileEntry;
    /**
     * Determines whether the item is a folder.
     * @param item The folder item.
     */
    static isFolder(item: FileEntry | FolderEntry): item is FolderEntry;
    /**
     * Formats the TCPS POD url from the "origin".
     * @param origin The origin.
     * @param path The relative path.
     */
    private static formatUrlFromOrigin;
    /**
     * @constructor Constructs a service object.
     * @param {Config} config The configuration options (e.g. service url). If not provided the default configuration will be used.
     * @param {Credentials} credentials The credentials to be attached to service requests.
     */
    constructor(config?: Partial<Configuration>);
    /**
     * Returns information the service knows about the current user.
     * @returns {Promise<ServiceResponse<UserInfoResponse>>} the information known about the caller.
     */
    listServers(): Promise<ServiceResponse<Server[]>>;
    /**
     * Returns the user details.
     * @param userId The user identifier.
     */
    getUserDetails(userId: string): Promise<ServiceResponse<UserDetails>>;
    /**
     * Returns the available projects on a server.
     * @param server The server.
     */
    listProjects(server: Server): Promise<ServiceResponse<Project[]>>;
    /**
     * Returns the project by it's identifier
     * @param id The project identifier
     * @param server The server (optional)
     */
    getProject(id: string, server?: Server): Promise<ServiceResponse<Project>>;
    /**
     * Return updated project after patch.
     * @param {string} projectId project's id.
     * @param {string} projectOrigin project's origin uri.
     * @param {Partial<Project>} patchObject Object with key:value pair.
     * @returns {Promise<ServiceResponse<Project>>} Service response.
     */
    patchProject(projectId: string, projectOrigin: string, patchObject: Partial<Project>): Promise<ServiceResponse<Project>>;
    /**
     * Return updated project after patch.
     * @param {project} project.
     * @returns {Promise<ServiceResponse<Project>>} Service response.
     */
    updateLastVisitedOnProject(project: Project): Promise<ServiceResponse<Project>>;
    /**
     * Returns the project members by project identifier
     * @param project The project
     */
    listProjectMembers(project: Project): Promise<ServiceResponse<UserDetails[]>>;
    /**
     * Creates new user group
     * @param {Project} project The project.
     * @param {string} name The project name.
     * @returns {Promise<ServiceResponse<UserGroup>>} Service response containing the created group.
     */
    createUserGroup(project: Project, name: string): Promise<ServiceResponse<UserGroup>>;
    /**
     * Removes give user group.
     * @param {Project} project The project.
     * @param {string} groupId The group id.
     * @returns {Promise<ServiceResponse<void>>} Service response.
     */
    removeUserGroup(project: Project, groupId: string): Promise<ServiceResponse<void>>;
    /**
     * Returns list of user groups.
     * @param {Project} project The project.
     * @returns {Promise<ServiceResponse<UserGroup[]>>} Service response containing user groups.
     */
    listUserGroups(project: Project): Promise<ServiceResponse<UserGroup[]>>;
    /**
     * Returns list of users in the given group.
     * @param {Project} project The project.
     * @param {string} groupId The group id.
     * @returns {Promise<ServiceResponse<User[]>>} Service response containing list of users.
     */
    listUsersInGroup(project: Project, groupId: string): Promise<ServiceResponse<User[]>>;
    /**
     * Adds users to the given group.
     * @param {Project} project The project.
     * @param {string} groupId The group id.
     * @param {string[]} userIds The list of user ids to add to the given group.
     * @returns {Promise<ServiceResponse<User[]>>} Service response containing added users.
     */
    addUsersToGroup(project: Project, groupId: string, userIds: string[]): Promise<ServiceResponse<User[]>>;
    /**
     * Removes users from the given group.
     * @param {Project} project The project.
     * @param {string} groupId The group id.
     * @param {string[]} userIds The list of user ids to remove from the given group.
     * @returns {Promise<ServiceResponse<void>>} Service response.
     */
    removeUsersFromGroup(project: Project, groupId: string, userIds: string[]): Promise<ServiceResponse<void>>;
    /**
     * Invite a user to project.
     * @param {Project} project The project.
     * @param {string} userEmail The user email.
     * @param {string} userRole The user role.
     * @returns {Promise<ServiceResponse<UserDetails>>} Service response.
     */
    inviteUserToProject(project: Project, userEmail: string, userRole: string): Promise<ServiceResponse<UserDetails>>;
    /**
     * Remove a user from project.
     * @param {string} project The project details from which user has to be removed.
     * @param {string} userId The user Id.
     * @returns {Promise<ServiceResponse<void>>} Service response.
     */
    removeUserFromProject(project: Project, userId: string): Promise<ServiceResponse<void>>;
    /**
     * List of users for the company id
     * @param {string} origin regions location of the projects
     * @param {string} companyId Company's id
     * @returns {Promise<ServiceResponse<User[]>>} Service response containing list of users.
     */
    listUsersByCompanyId(origin: string, companyId: string): Promise<ServiceResponse<User[]>>;
    /**
     * Get project settings.
     * @param {Project} project The project.
     * @returns {Promise<ServiceResponse<ProjectSettings>>} Service response containing project settings.
     */
    getProjectSettings(project: Project): Promise<ServiceResponse<ProjectSettings>>;
    /**
     * Put project settings.
     * @param {Project} project The project.
     * @param {ProjectSettings} projectSettings The project settings.
     * @returns {Promise<ServiceResponse<void>>} Service response.
     */
    putProjectSettings(project: Project, projectSettings: ProjectSettings): Promise<ServiceResponse<void>>;
    /**
     * Returns the folder items.
     * @param folderId The folder id.
     */
    listFolderEntries(parent: Project | FolderEntry): Promise<ServiceResponse<Array<FileEntry | FolderEntry>>>;
    /**
     * Returns the format processing status for given file.
     * @param {string} project The Project.
     * @param {string} fileId The file id.
     * @param {string} versionId Optional version identifier.
     * @param {string} format Optional file format.
     * @returns {Promise<ServiceResponse<StatusResponse>>} The valid return values are integer from 0 to 100, negative values indicate processing error.
     */
    getFileStatus(project: Project, fileId: string, versionId?: string, format?: string): Promise<ServiceResponse<StatusResponse>>;
    /**
     * Returns the file.
     * @param project The Project.
     * @param fileId The file id.
     */
    getFile(project: Project, fileId: string): Promise<ServiceResponse<FileEntry>>;
    /**
     * Updates the file. Renaming, moving, and setting assimilation notification supported.
     * @param {Project} project The Project.
     * @param {UpdateFileEntryRequest} updateRequest The update request.
     * @returns {Promise<ServiceResponse<FileEntry>>} Service response containing udpate file entry.
     */
    updateFile(project: Project, updateRequest: UpdateFileEntryRequest): Promise<ServiceResponse<FileEntry>>;
    /**
     * Returns the folder.
     * @param project The Project.
     * @param folderId The folder id.
     */
    getFolder(project: Project, folderId: string): Promise<ServiceResponse<FolderEntry>>;
    /**
     * Returns the file download url application can use to download file content.
     * @param {FileEntry} file The file.
     * @param {string} versionId Optional version identifier.
     * @param {string} format Optional format.
     * @returns {ServiceResponse<void>} Service response.
     */
    getFileDownloadUrl(file: FileEntry, versionId?: string, format?: string): Promise<ServiceResponse<UrlResponse>>;
    /**
     * Uploads the given files.
     * @param {Project} The project
     * @param {File[]} files The files to upload.
     * @param {parentId} parentId The parent identifier.
     * @param {FileParentType} parentType The parent type.
     * @returns {Array<ServiceResponse<FileEntry>>} Array of service responses containing created file entries.
     */
    uploadFileContent(project: Project, files: File[], parentId: string, parentType: FileParentType): Promise<Array<ServiceResponse<FileEntry>>>;
    /**
     * Makes an attempt to process or reprocess the given file.
     * @param {Project} The project
     * @param {FileEntry} file The file entry.
     * @param {format} accepted values: "TRB" or "BSQ", default is "TRB".
     * @returns {ServiceResponse<void>} The service response.
     */
    assimilateFile(project: Project, file: FileEntry, format?: 'TRB' | 'BSQ'): Promise<ServiceResponse<void>>;
    /**
     * Uploads the presentation file content connected to the parent file.
     * @param file The file.
     * @param parent The parent file.
     * @param parentVersionId The parent file version id.
     */
    putPresentationFileContent(file: File, parent: FileEntry, format: string, parentVersionId?: string): Promise<ServiceResponse<void>>;
    /**
     * Gets an image URL.
     * @param source The source object.
     * @param path The image path.
     */
    getImage(source: ConnectObject | undefined, path: string): Promise<string>;
    /**
     * Returns the model placement information.
     * @param file The model file.
     */
    getPlacement(file: FileEntry): Promise<ServiceResponse<Placement>>;
    /**
     * Create or update model placement for a given file.
     * @param file The model file.
     * @param placement The alignment.
     */
    putPlacement(file: FileEntry, placement: Placement): Promise<ServiceResponse<Placement>>;
    /**
     * Returns the todos.
     * @param project The project.
     */
    listToDos(project: Project): Promise<ServiceResponse<ToDo[]>>;
    /**
     * Returns the todo.
     * @param project The project.
     * @param todoId The project.
     */
    getToDo(project: Project, todoId: string): Promise<ServiceResponse<ToDo>>;
    /**
     * Creates a new todo and returns it.
     * @param project The project.
     * @param todo The todo data.
     */
    createToDo(project: Project, todo: ToDo): Promise<ServiceResponse<ToDo>>;
    /**
     * Updates the todo.
     * @param {Project} project The project.
     * @param {ToDo} todo The updated todo data.
     * @returns {Promise<ServiceResponse<ToDo>>} Service response containing updated todo.
     */
    updateToDo(project: Project, todo: ToDo): Promise<ServiceResponse<ToDo>>;
    /**
     * Removes the todo.
     * @param project The project.
     * @param todoId The todo identifier.
     * @returns {Promise<ServiceResponse<void>>} Service response.
     */
    removeToDo(project: Project, todoId: string): Promise<ServiceResponse<void>>;
    /**
     * Returns the todo comments.
     * @param todo The todo.
     */
    listToDoComments(todo: ToDo): Promise<ServiceResponse<Comment[]>>;
    /**
     * Returns comments related to the given entity.
     * @param {Project} project The project.
     * @param {string} entityId The entity identifier.
     * @param {CommentObjectType} entityType The entity type.
     */
    listComments(project: Project, entityId: string, entityType: CommentObjectType): Promise<ServiceResponse<Comment[]>>;
    /**
     * Returns the attachements.
     * @param origin The origin.
     * @param projectId The project id.
     * @param entityId The entity id.
     * @param entityType The entity type. Supported types are "TODO" and "COMMENT".
     */
    listAttachments(origin: string, projectId: string, entityId: string, entityType: 'TODO' | 'COMMENT'): Promise<ServiceResponse<Attachment[]>>;
    /**
     * Returns the todo attachments.
     * @param todo The todo.
     */
    listToDoAttachments(todo: ToDo): Promise<ServiceResponse<Attachment[]>>;
    /**
     * Adds attachment to entity.
     * @param origin The origin.
     * @param projectId The project id.
     * @param entityId The target entity.
     * @param entityType The target type. Supported types are "TODO" and "COMMENT".
     * @param attachmentId The entity id to attach, or url if attachment type is "URL".
     * @param attachmentType The type of the attached entity. Supported types are "VIEW", "FILE", "CLASHSET", "CLASHITEM", "VIEW2D". If target type is "COMMENT, also "URL" is supported.
     * @param embedded Flag to indicate embedded object attachment, apply only to views. Default is false.
     * @param urlName Required if when type is is "URL".
     */
    addAttachmentToEntity(origin: string, projectId: string, entityId: string, entityType: string, attachmentId: string, attachmentType: string, embedded?: boolean, urlName?: string): Promise<ServiceResponse<Attachment>>;
    /**
     * Attaches a view to todo.
     * @param todo The todo.
     * @param view The view.
     */
    attachViewToTodo(todo: ToDo, view: View): Promise<ServiceResponse<Attachment>>;
    /**
     * Remove attachment from entity.
     * @param origin The origin.
     * @param projectId The project id.
     * @param entityId The target entity.
     * @param entityType The target type.
     * @param attachmentId The attachment id.
     * @param attachmentType The type of the attached entity.
     */
    removeAttachment(origin: string, projectId: string, entityId: string, entityType: string, attachmentId: string, attachmentType: string): Promise<ServiceResponse<void>>;
    /**
     * Creates a comment.
     * @param {Project} project The project.
     * @param {CreateCommentRequest} comment The comment data.
     */
    createComment(project: Project, comment: CreateCommentRequest): Promise<ServiceResponse<Comment>>;
    /**
     * Updates a comment.
     * @param {Comment} comment The comment data.
     * @returns {Promise<ServiceResponse<Comment>>} Service response containing udpated comment.
     */
    updateComment(comment: Comment): Promise<ServiceResponse<Comment>>;
    /**
     * Deletes a comment.
     * @param project The project.
     * @param commentId The comment identifier.
     */
    deleteComment(project: Project, commentId: string): Promise<ServiceResponse<void>>;
    /**
     * Returns the views.
     * @param project The project.
     */
    listViews(project: Project): Promise<ServiceResponse<View[]>>;
    /**
     * Returns the view.
     * @param project The project.
     * @param viewId The view id.
     */
    getView(project: Project, viewId: string): Promise<ServiceResponse<View>>;
    /**
     * Creates a new view.
     * @param project The project.
     * @param view The view data.
     */
    createView(project: Project, view: View): Promise<ServiceResponse<View>>;
    /**
     * Updates the view.
     * @param {Project} project The project.
     * @param {View} view The view data.
     * @returns {Promise<ServiceResponse<View>>} Service response containing the updated view data.
     */
    updateView(project: Project, view: View): Promise<ServiceResponse<View>>;
    /**
     * Removes the view.
     * @param project The project.
     * @param viewId The view identifier.
     * @param [force=false] Flag to delete explicit view even if it is attached to ToDos. Default is false.
     * @returns {Promise<ServiceResponse<void>>} Service response.
     */
    removeView(project: Project, viewId: string, force?: boolean): Promise<ServiceResponse<void>>;
    /**
     * Creates a new view group.
     * @param project The project.
     * @param name The name of the group.
     * @param views List of views to add to the group. Optional.
     * @returns {Promise<ServiceResponse<ViewGroup>>} Service response containing the created view group.
     */
    createViewGroup(project: Project, name: string, views?: string[]): Promise<ServiceResponse<ViewGroup>>;
    /**
     * Removes the view group.
     * @param project The project.
     * @param viewGroupId The view group identifier.
     * @returns {Promise<ServiceResponse<void>>} Service response.
     */
    removeViewGroup(project: Project, viewGroupId: string): Promise<ServiceResponse<void>>;
    /**
     * Updates the view group. Name and views modifications supported.
     * @param project The project.
     * @param viewGroup The view group.
     * @returns {Promise<ServiceResponse<ViewGroup>>} Service response.
     */
    updateViewGroup(project: Project, viewGroup: ViewGroup): Promise<ServiceResponse<ViewGroup>>;
    /**
     * Returns the view groups.
     * @param project The project.
     * @returns {Promise<ServiceResponse<ViewGroup[]>>} Service response containing view groups.
     */
    listViewGroups(project: Project): Promise<ServiceResponse<ViewGroup[]>>;
    /**
     * Returns the tags.
     * @param project The project.
     */
    listTags(project: Project): Promise<ServiceResponse<Tag[]>>;
    /**
     * Creates a new tag.
     * @param project The project.
     * @param tag The Tag.
     */
    createTag(project: Project, tag: Tag): Promise<ServiceResponse<Tag>>;
    /**
     * Adds object to a tag.
     * @param tag The Tag.
     * @param id The object id.
     * @param objectType The object type.
     */
    addObjectToTag(tag: Tag, id: string, objectType: TagObjectType): Promise<ServiceResponse<void>>;
    /**
     * Removes object from a tag.
     * @param tag The Tag.
     * @param id The object id.
     * @param objectType The object type.
     */
    removeObjectFromTag(tag: Tag, id: string, objectType: TagObjectType): Promise<ServiceResponse<void>>;
    /**
     * List tags related to an object.
     * @param project The project.
     * @param objectId The object id.
     * @param objectType The object type.
     */
    listTagsInObject(project: Project, objectId: string, objectType: TagObjectType): Promise<ServiceResponse<Tag[]>>;
    /**
     * Get links by file.
     * @param {Project} project The project.
     * @param {string} id The file id.
     * @param {string} versionId The version id. Optional.
     * @param [includeDeleted=false] Indicates whether to include deleted links.
     * @param [full=false] Indicates whether to get full or mini version of listing. Default is mini.
     * @returns {Promise<ServiceResponse<Link[]>>} Service response containing links related to the given file.
     */
    getLinksByFile(project: Project, id: string, versionId?: string, includeDeleted?: boolean, full?: boolean): Promise<ServiceResponse<Link[]>>;
    /**
     * Get links by object.
     * @param {Project} project The project.
     * @param {string} objectId The object id.
     * @param {string} objectType The object type. Supporter types are FOLDER, FILE, and TODO.
     * @param [includeDeleted=false] Indicates whether to include deleted links.
     */
    getLinksByEntity(project: Project, objectId: string, objectType: 'FOLDER' | 'FILE' | 'TODO', includeDeleted?: boolean): Promise<ServiceResponse<Link[]>>;
    /**
     * Creates object link.
     * @param {Project} project The project.
     * @param {string} versionId The fileversion id.
     * @param {string[]} objectIds The object ids.
     * @param {string} targetId The target id.
     * @param {string} targetType The target type. Supported types are file, todo, view, clash, and url.
     * @param {string} urlName The URL name (in case the target type is URL).
     * @returns {Promise<ServiceResponse<void>>} Service response containing created link.
     */
    createObjectLink(project: Project, versionId: string, objectIds: string[], targetId: string, targetType: LinkTargetType, urlName?: string): Promise<ServiceResponse<Link>>;
    /**
     * Deletes object link.
     * @param {Project} project The project.
     * @param {string} linkId The link id.
     * @returns {Promise<ServiceResponse<void>>} Service response.
     */
    deleteObjectLink(project: Project, linkId: string): Promise<ServiceResponse<void>>;
    /**
     * Deletes clash.
     * @param {Project} project The project.
     * @param {string} clashId The clash id.
     * @returns {Promise<ServiceResponse<ClashItem[]>>} Service response.
     */
    getClashItems(project: Project, clashId: string): Promise<ServiceResponse<ClashItem[]>>;
    /**
     * Deletes clash.
     * @param {Project} project The project.
     * @param {string} clashId The clash id.
     * @returns {Promise<ServiceResponse<void>>} Service response.
     */
    deleteClash(project: Project, clashId: string): Promise<ServiceResponse<void>>;
    /**
     * Returns the share.
     * @param origin The service origin.
     * @param sToken The share token.
     * @returns {Promise<ServiceResponse<Share>>} Service response.
     */
    getShare(origin: string, sToken: string): Promise<ServiceResponse<Share>>;
}
/**
 * The default instance of the TCPS client.
 */
export declare const TCPSClient: TCPS;
export default TCPSClient;
