import { Credentials } from './credentials';
import { AuthResponse, TIDConfig } from './tid';
export interface TIDCredentialsParams extends TIDConfig {
}
export interface TIDUserCredentials {
    password: string;
    username: string;
}
/**
 * Service credentials that must be attached to authenticate each request.
 * Occasionally credentials can expire in the middle of a long-running application.
 */
export declare class TIDCredentials extends Credentials {
    readonly params: TIDCredentialsParams;
    userCredentials?: TIDUserCredentials | undefined;
    readonly onRefreshed?: ((tidCredentials: TIDCredentials) => void) | undefined;
    tokens?: AuthResponse;
    private readonly service;
    /**
     * Creates a TIDCredentials object with a given set of credential information as positional arguments.
     * @param {TIDCredentialsParams} params The TID Credentials configuration options.
     * @param {TIDUserCredentials} [userCredentials] The user credentials. Optional.
     * @param {(TIDCredentials) => void} [onRefreshed] Called when TID tokens are refreshed. Optional.
     * @example Creating a new credentials object
     *   credentials = new CDM.TIDCredentials({
     *       authUrl: "https://identity.trimble.com/",
     *       clientId: "xxx",
     *       clientSecret: "yyy",
     *     },
     *     { username: "name", password: "pass" }
     *   )
     */
    constructor(params: TIDCredentialsParams, userCredentials?: TIDUserCredentials | undefined, onRefreshed?: ((tidCredentials: TIDCredentials) => void) | undefined);
    /**
     * Refreshes the credentials.
     * Users should call get() before attempting to forcibly refresh credentials.
     * @note Subclasses should override this class to reset the {token} on the credentials object.
     * @see get
     */
    refresh(): Promise<void>;
    /**
     * Returns whether the token invalid
     */
    invalidToken(): boolean;
}
